@@ -57,6 +57,22 @@ def load_api_config(api_config_dict: Dict[str, str]) -> PrintNannyApiConfig:
     return PRINTNANNY_CLOUD_API
 
 
+def sync_printnanny_cloud_data():
+    logger.info("Attempting to sync PrintNanny Cloud data...")
+    cmd = [PRINTNANNY_BIN, "cloud", "sync-models"]
+    try:
+        p = subprocess.run(cmd, capture_output=True)
+        stdout = p.stdout.decode("utf-8")
+        stderr = p.stderr.decode("utf-8")
+        if p.returncode != 0:
+            logger.error(
+                f"Failed to get printnanny settings cmd={cmd} returncode={p.returncode} stdout={stdout} stderr={stderr}"
+            )
+            return
+    except Exception as e:
+        logger.error("Error running cmd %s %s", cmd, e)
+
+
 async def load_printnanny_cloud_data():
     cmd = [PRINTNANNY_BIN, "cloud", "show"]
     # run /usr/bin/printnanny cloud show --format json
@@ -71,11 +87,8 @@ async def load_printnanny_cloud_data():
             return
 
         cloud_data = json.loads(stdout)
-        pi = cloud_data.get("pi")
-        if pi is None:
-            logger.error("Failed to parse pi from data=%s", cloud_data)
         # try setting global PRINTNANNY_CLOUD_PI var
-        await load_pi_model(pi)
+        await load_pi_model(cloud_data)
     except Exception as e:
         logger.error("Error running cmd %s %s", cmd, e)
 
